"""
Copyright (c) 2025 Riverlane Ltd. All rights reserved.

deltakit: A quantum error correction SDK
"""

from __future__ import annotations

from ._version import version as __version__

__all__ = ["__version__"]
